@@ -4,17 +4,20 @@
 
 #Takes file as first argument
 get_icon_dir_for_file() {
-	CATEGORY="$( printf "%s" "$1" | grep -Po "/.*\K/.*(?=/.*)" )"
-	[ -z "$CATEGORY" ] && CATEGORY=apps
-	if [ "$(file --mime-type "$1")" = "image/png" ] ; then
-		RESOLUTION="$(printf "%s" "$1" | grep -Po "\K[0-9]*x[0-9]*@?[0-9]*(?=/.*)")"
-		[ -z "$RESOLUTION" ] && RESOLUTION="scaleable" # Just put it in scaleable, lintian will throw a warning
-		printf "$RESOLUTION/$CATEGORY"
-	elif printf "%s" "$1" | grep -q "symbolic/.*\.svg" ; then
-		printf "symbolic/$CATEGORY"
-	else
-		printf "scaleable/$CATEGORY"
-	fi
+	printf "%s\n" "$1" | sed 's|/[^/]*$||' | rev | tr '/' '\n' | while read ps ; do
+		ps="$( printf "%s\n" "$ps" | rev )"
+		r="$(printf "%s\n" "$ps" | grep -Po "\K[0-9]*x[0-9]*@?[0-9]*" )"
+		if [ -n "$r" ]; then
+			printf "resolution %s\n" "$r"
+		elif [ "$ps" = "symbolic" ] ; then
+			printf "resolution symbolic\n"
+		elif [ "$ps" = "icons" ] ; then
+			break # We exit the loop if we hit the icons directory
+		else
+			printf "category %s\n" "$ps"
+		fi
+	done | awk 'BEGIN{ resolution="scaleable"; category="apps"} /^resolution/{ resolution = $2 } /^category/{ category = $2 } END{ print resolution "/" category}'
+
 }
 
 find -maxdepth 1 \( -name 'treuchtlingen-foxde-*' -or -name 'foxde-*' \) -printf '%f\n' | while read pkg ; do
@@ -29,15 +32,17 @@ find -maxdepth 1 \( -name 'treuchtlingen-foxde-*' -or -name 'foxde-*' \) -printf
 				DEST_DIR="/usr/share/desktop-directories/" ;;
 			menus)
 				DEST_DIR="/etc/xdg/menus/applications-merged/" ;;
+			bin)
+				DEST_DIR="/usr/bin/"
 		esac
 		if [ -n "$DEST_DIR" ] ; then
 			mkdir -p "debian/$pkg$DEST_DIR"
 			case "$component" in
 				icons)
 					find "$pkg/$component" -type f -printf "%P\n" | while read f ; do
-						DEST_DIR="debian/$pkg$DEST_DIR/$(get_icon_dir_for_file "$f")"
-						mkdir -p "$DEST_DIR" 
-						cp -ra "$pkg/$component/$f" "$DEST_DIR/$(basename "$f")"
+						ICON_DEST="debian/$pkg$DEST_DIR/$(get_icon_dir_for_file "$pkg/$component/$f")"
+						mkdir -p "$ICON_DEST" 
+						cp -ra "$pkg/$component/$f" "$ICON_DEST/$(basename "$f")"
 					done ;;
 				*)
 					for f in $(ls "$pkg/$component") ; do
